# Part of Odoo. See LICENSE file for full copyright and licensing details.

from . import test_address
from . import test_common
from . import test_customize
from . import test_delivery_controller
from . import test_delivery_express_checkout_flows
from . import test_delivery_ui
from . import test_ecommerce_access
from . import test_express_checkout_flows
from . import test_fuzzy
from . import test_sale_process
from . import test_sitemap
from . import test_website_sale_add_to_cart_snippet
from . import test_website_sale_cart_abandoned
from . import test_website_sale_cart_notification
from . import test_website_sale_cart_payment
from . import test_website_sale_cart_recovery
from . import test_website_sale_cart
from . import test_website_sale_configurator
from . import test_website_sale_mail
from . import test_website_sale_pricelist
from . import test_website_sale_product_attribute_value_config
from . import test_website_sale_image
from . import test_website_sequence
from . import test_website_sale_show_compare_list_price
from . import test_website_sale_visitor
from . import test_website_editor
from . import test_website_sale_reorder_from_portal
from . import test_website_sale_snippets
from . import test_website_sale_invoice
